import { SvelteComponentTyped } from "svelte";
import type { DataTypes, RuleDefinition } from "./common";
declare const __propDef: {
    props: {
        /** Two-way binding for controlling and reading the Dropdown selection
            - see {@link components/use-dropdown} */ selected?: string | string[] | undefined;
        /** Two-way binding for controlling and reading the Modal state
            - see {@link components/use-modal} */ active?: boolean | undefined;
        /** Two-way binding for controlling and reading the Calendar date, time, or datetime
            - see {@link components/use-calendar} */ date?: Date | undefined;
        /** Two-way binding for controlling and reading the Slider value
            - see {@link components/use-slider} */ position?: number | undefined;
        /** Two-way binding for controlling and reading raw input value.
        
            May be used together with {@link components/use-format}. */ value?: DataTypes | undefined;
        /** Optional value validator. Uses Semantic UI validator syntax.
        
            The same as {@link components/use-validate}.
        
            Ususally takes the value generated with {@link data/rule-book.rule}. */ validate?: RuleDefinition | undefined;
        /** Id of the input element, takes precendence over tag position */ forId?: string | undefined;
    };
    events: {
        [evt: string]: CustomEvent<any>;
    };
    slots: {};
};
export type DataBindProps = typeof __propDef.props;
export type DataBindEvents = typeof __propDef.events;
export type DataBindSlots = typeof __propDef.slots;
/**
 * Svelte data binder for Semantic-UI `Dropdown`, `Modal`, `Calendar`, and `Slider` components.
 * The <Data> tag must be a child of the corresponding Semantic UI component.
 *
 * https://semantic-ui.com/modules/dropdown.html
 *
 * For `Dropdown` coponent, type of `selected` binding is `string` for a select,
 * or `string[]` for a multi-select.
 * Invalid value will reset the select, or get removed from the multi-select.
 *
 * For `Modal` component, changing the `boolean` variable bound to `active` will show
 * or hide the dialofue.
 *
 * `Caledar` `date` binding takes `Date` object, which may represent calendar date,
 * time, or date-and-time.
 *
 * `Slider` component takes `value` binding of type `number`.
 *
 * Example:
 * ```
 * <select class="ui selection dropdown" use:dropdown>
 *     <Data bind:selected={gender} />
 *     <option value="M">Male</option>
 *     <option value="F">Female</option>
 * </select>
 *
 * <div id="md" class="ui modal page" use:modal>
 *     <Data bind:active={show} />
 *     ...
 * </div>
 *
 * <div class="ui calendar" use:calendar>
 *     <Data bind:date={alarm} />
 *     <div class="ui input right icon">
 *         <i class="clock outline icon" />
 *         <input type="text" placeholder="Time" />
 *     </div>
 * </div>
 *
 * <div class="ui labeled ticked slider" use:slider>
 *     <Data bind:position={num} />
 * </div>
 * ```
 */
export default class DataBind extends SvelteComponentTyped<DataBindProps, DataBindEvents, DataBindSlots> {
}
export {};
