/**
 * 'fmt' and 'parse' utility object, input formatter classes.
 * @module data/input-formatter
 */
import type { DataTypes, Formatter } from "./common";
export declare class NumberFmt implements Formatter {
    precision: number;
    separator: string;
    constructor(prec?: number, sep?: string);
    parse(val: string): number | undefined;
    format(val: DataTypes): string;
}
export declare class MoneyFmt implements Formatter {
    numFormatter: NumberFmt;
    /** For exmaple: '$' */
    prefix: string;
    /** For example 'CAD' */
    suffix: string;
    prefixRegex: RegExp;
    suffixRegex: RegExp;
    constructor(prec?: number, pref?: string, suff?: string);
    parse(val: string): number | undefined;
    format(val: DataTypes): string;
}
/** How to upper-case the text */
export type CaseMode = "upper" | "lower" | "title";
export declare class TextFmt implements Formatter {
    caseMode: CaseMode;
    constructor(caseMode: CaseMode);
    format(val: DataTypes): string;
}
export declare class ListFmt implements Formatter {
    separator: string;
    constructor(sep?: string);
    parse(val: string): string[];
    format(val: DataTypes): string;
}
export declare function parseDate(val: string): Date | undefined;
export declare function formatDate(val: DataTypes): string;
export declare class DateFmt implements Formatter {
    parse(val: string): Date | undefined;
    format(val: DataTypes): string;
}
